SelectedObjectDrawableUpdatedNotification class
A notification that is dispatched when the selected ObjectDrawable of ObjectWidget changes.
Note that drawable will only be valid until the drawable is modified (moved, scaled, rotated, etc...),
so use this callback as a reference that the selected object drawable changed internally and nothing
more to avoid issues.
Use PainterController.selectedObjectDrawable if you want to do any operations on the selected object drawable.
- Inheritance
-
- Object
- Notification
- SelectedObjectDrawableUpdatedNotification
Constructors
- SelectedObjectDrawableUpdatedNotification(ObjectDrawable? drawable)
-
Creates a SelectedObjectDrawableUpdatedNotification with the given
drawable.
Properties
- drawable → ObjectDrawable?
-
The Drawable the notification represents.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
debugFillDescription(
List< String> description) → void -
Add additional information to the given description for use by toString.
inherited
-
dispatch(
BuildContext? target) → void -
Start bubbling this notification at the given build context.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited